diff --git a/linear-algebra/cholesky.lisp b/linear-algebra/cholesky.lisp
index d39f250..1387ee4 100644
--- a/linear-algebra/cholesky.lisp
+++ b/linear-algebra/cholesky.lisp
@@ -72,6 +72,16 @@
   solution returned in it.  If x-spec is a marray, the solution will
   be returned in it.")
 
+(defmfun cholesky-invert (cholesky)
+  "gsl_linalg_cholesky_invert"
+  (((mpointer cholesky) :pointer))
+  :inputs (cholesky)
+  :outputs (cholesky)
+  :documentation			; FDL
+  "This function computes the inverse of the matrix cholesky which must have
+  been previously computed by #'cholesky-decomposition. The inverse of the
+  original matrix A is stored in cholesky on output.")
+
 ;;; Examples and unit test, from linalg/test.c
 
 (defun test-cholesky-solve-dim (matrix)
@@ -90,6 +100,10 @@
 	   (setf (maref decomp row col) 0.0d0)))
     (matrix-product decomp decomp nil 1.0d0 0.0d0 :notrans :trans)))
 
+(defun test-cholesky-invert-dim (matrix)
+  "Invert using Cholesky decomposition"
+  (cholesky-invert (cholesky-decomposition (copy matrix))))
+
 (save-test cholesky
  (test-cholesky-solve-dim *hilb2*)
  (test-cholesky-solve-dim *hilb3*)
@@ -98,4 +112,8 @@
  (test-cholesky-decomp-dim *hilb2*)
  (test-cholesky-decomp-dim *hilb3*)
  (test-cholesky-decomp-dim *hilb4*)
- (test-cholesky-decomp-dim *hilb12*))
+ (test-cholesky-decomp-dim *hilb12*)
+ (test-cholesky-invert-dim *hilb2*)
+ (test-cholesky-invert-dim *hilb3*)
+ (test-cholesky-invert-dim *hilb4*)
+ (test-cholesky-invert-dim *hilb12*))
